@@ -59,41 +59,21 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
             pos_size = input(
                 "Choose your Position Size for {} per trade in %: ".format(symbol))
             pos_size = check_pos_size(pos_size)
-            symbol_settings.append(Symbol(name=symbol, position_size=pos_size))
-        return make_pickle_file(setting_path, setting_name, token, api_key, api_secret, symbol_settings)
+            new_symbol = Symbol(name=symbol, position_size=pos_size)
+            symbol_settings.append(new_symbol)
+        return make_pickle_file(setting_name, token, api_key, api_secret, symbol_settings)
 
 
-def position_symbol_sizes(symbols):
-    output = ''
-    for symbol in symbols:
-        output += '\n\t{} Position Size: {} %\n\n'.format(
-            symbol.name, symbol.position_size)
-    return output
-
-
-def check_settings(settings, broker):
-    while True:
-        qr = input("Start Algo Trader Bot with"
-                   "\n\tBroker: " + broker.replace('_', ' ').title() +
-                   "\n\tToken: {}..."
-                   "\n\tAPI ID: {}"
-                   "\n\tAPI Secret: ...{}"
-                   "{}"
-                   "Do you want to continue? ['y' for yes, 'n' for no, 'c' for"
-                   " change settings] "
-                   .format(settings.token[:4], settings.api_key, settings.api_secret[-4:], position_symbol_sizes(settings.symbols)))
-        if qr == '' or qr[0].lower() not in ['y', 'n', 'c']:
-            print("'y' for yes, 'n' for no or 'c' for "
-                  "change settings (you don't have to write '').")
-        elif qr[0].lower() == 'c':
-            return file_create_input(check_exist=False)
-        else:
-            answer = qr[0].lower()
-            if answer == 'y':
-                return settings
-            else:
-                print("Shutting down...")
-                sys.exit()
+def make_pickle_file(filename, token, api_key, api_secret, symbol_settings):
+    settings = BrokerSettings
+    settings.token = token
+    settings.api_key = api_key
+    settings.api_secret = api_secret
+    for setting in symbol_settings:
+        settings.symbols.append(setting)
+    pickle.dump(settings, file=open(
+        os.path.join(settings_path, filename), 'wb'))
+    return settings
 
 
 def check_pos_size(pos_size, max_position_size=10):
@@ -110,15 +90,38 @@ def check_pos_size(pos_size, max_position_size=10):
     return pos_size
 
 
-def make_pickle_file(filepath, filename, token, api_key, api_secret, symbol_settings):
-    settings = BrokerSettings
-    settings.token = token
-    settings.api_key = api_key
-    settings.api_secret = api_secret
-    for setting in symbol_settings:
-        settings.symbols.append(setting)
-    pickle.dump(settings, file=open(os.path.join(filepath, filename), 'wb'))
-    return settings
+def check_settings(settings, symbols, broker, strategy):
+    print('check settings')
+    while True:
+        qr = input("Start Algo Trader Bot with"
+                   "\n\tBroker: " + broker.replace('_', ' ').title() +
+                   "\n\tToken: {}..."
+                   "\n\tAPI ID: {}"
+                   "\n\tAPI Secret: ...{}"
+                   "{}"
+                   "Do you want to continue? ['y' for yes, 'n' for no, 'c' for"
+                   " change settings] "
+                   .format(settings.token[:4], settings.api_key, settings.api_secret[-4:], position_symbol_sizes(settings.symbols)))
+        if qr == '' or qr[0].lower() not in ['y', 'n', 'c']:
+            print("'y' for yes, 'n' for no or 'c' for "
+                  "change settings (you don't have to write '').")
+        elif qr[0].lower() == 'c':
+            return file_create_input(check_exist=False, symbols=symbols, broker=broker, strategy=strategy)
+        else:
+            answer = qr[0].lower()
+            if answer == 'y':
+                return settings
+            else:
+                print("Shutting down...")
+                sys.exit()
+
+
+def position_symbol_sizes(symbols):
+    output = ''
+    for symbol in symbols:
+        output += '\n\t{} Position Size: {} %\n\n'.format(
+            symbol.name, symbol.position_size)
+    return output
 
 
 parser = argparse.ArgumentParser()
@@ -157,7 +160,8 @@ if args.run in ['run', 'Run', 'RUN']:
         sys.exit()
 
     if args.start == 'start':  # start without input prompt
-        start_settings = bot_settings(symbols=symbols, broker=broker, strategy=args.strategy)
+        start_settings = bot_settings(
+            symbols=symbols, broker=broker, strategy=args.strategy)
     else:
         start_settings = file_create_input(
             symbols=symbols, broker=broker, strategy=args.strategy)
@@ -168,10 +172,12 @@ if args.run in ['run', 'Run', 'RUN']:
         from algo_trader.strategies import Lotus
         from algo_trader.clients import BitmexClient
 
-        client = BitmexClient(api_key=start_settings.api_key, api_secret=start_settings.api_secret, testnet=testnet)
-        lotus = Lotus(client, symbols, start_settings, setting_file_name=setting_file_name)
+        client = BitmexClient(api_key=start_settings.api_key,
+                              api_secret=start_settings.api_secret, testnet=testnet)
+        lotus = Lotus(client, symbols, start_settings,
+                      setting_file_name=setting_file_name)
         lotus.run()
-    
+
     """
     any custom made strategy has to be run with the -strategy <strategy name> argument.
     You have to create a new strategy class in /strategies folder to run it.
